/*
 *****************************************************
 *
 *  SaVi by Robert Thurman (thurman@geom.umn.edu) and
 *          Patrick Worfolk (worfolk@alum.mit.edu).
 *
 *  Copyright (c) 1997 by The Geometry Center.
 *  This file is part of SaVi.  SaVi is free software;
 *  you can redistribute it and/or modify it only under
 *  the terms given in the file COPYRIGHT which you should
 *  have received along with this file.  SaVi may be
 *  obtained by emailing savi@geom.umn.edu.
 *
 *****************************************************
 *
 * constants.h
 *
 */

#ifndef _CONSTANTS_H_
#define _CONSTANTS_H_

#define OK 1
#define NOT_OK -1

#define TRUE 1
#define FALSE 0

#define HANDLE_FILE "oogl/savi.oogl"
#define HANDLE_FILE_INVERTED "oogl/savi_inverted.oogl"

#define TCL_DIR "tcl"
#ifndef PI
#define PI 3.14159265358979324
#endif
#define TWOPI 6.2831853071795865
#define HALFPI 1.570796326794897

#define DEG_TO_RAD (PI/180.0)
#define RAD_TO_DEG (180.0/PI)
#define SECS_PER_DAY (3600*24)
#define ANOMALY_COMPUTATION_TOLERANCE 1e-5

/*  The gravitational parameter MU. Units are km^3/s^2  */
#define EARTH_MU 398601.2
#define EARTH_RADIUS 6378.14 /* km */

/* Earth rotation rate (in geocentric equatorial coordinates */
/* is (2*PI+2*PI/365.25) radians per day. */
/* The second term accounts for the fact that the earth is orbiting */
/* the sun. The factor is 1/365.25 rather than 1/365 because of leap */
/* year effects. The rate below is radians per second. */
#define EARTH_ROTATION_RATE (TWOPI*1.160576e-5)
#define EARTH_OBLATENESS 1.0826e-3

/*  Parameters for coverage display */
#define IMAGE_HEIGHT 300
#define IMAGE_WIDTH  600
#define IMAGE_SIZE (IMAGE_HEIGHT*IMAGE_WIDTH)
#define ELEV_MASK_ANGLE (30*DEG_TO_RAD)
#define SAT_CONE_ANGLE (PI/2.86)
#define LONGITUDE_CENTER_LINE (-90.0)
#define COVERAGE_ANGLE 0.0

/* ground tracks interval is in days */
#define TRACKS_INTERVAL 1.0 

/* parameters for fisheye view */
#define FISHEYE_SIZE 300

/* parameters for orbit display */
#define ORBIT_SEGMENTS 40

/* bitmap of geographical boundaries for coverage */
#define SINUSOIDAL_BITMAP_NAME "maps/world90W.sinu.pbm"
#define RECTANGULAR_BITMAP_NAME "maps/world90W.cyl.pbm"

#endif
/* !_CONSTANTS_H_ */


