/*
 *****************************************************
 *
 *  SaVi by Robert Thurman (thurman@geom.umn.edu) and
 *          Patrick Worfolk (worfolk@alum.mit.edu).
 *
 *  Copyright (c) 1997 by The Geometry Center.
 *  This file is part of SaVi.  SaVi is free software;
 *  you can redistribute it and/or modify it only under
 *  the terms given in the file COPYRIGHT which you should
 *  have received along with this file.  SaVi may be
 *  obtained by emailing savi@geom.umn.edu.
 *
 *****************************************************
 *  
 * stats_utils.h
 *
 */
#ifndef _STATS_UTILS_H_
#define _STATS_UTILS_H_

#include <Satellite.h>

#define MIN(A, B) ((A) < (B) ? (A) : (B))

typedef enum {
  SINUSOIDAL=0, RECTANGULAR, NUM_PROJECTIONS
} coverage_projections;

enum {
  MASK_ELEVATION=0, SATELLITE_CONE
};

/* The coverage grid structure. */
typedef struct grid {
    unsigned int height,width;
    int *data;
    int *covered;
    int *noaccess;
    int count;
  } grid;


grid *create_grid(unsigned int h, unsigned int w);
void destroy_grid(grid *g);
void clear_grid(grid *g);
void fill_grid(const Satellite_list SL, int projection, int fp_angle_type,
	       double footprint_angle, const CentralBody *pcb, grid *g);

void init_coverage_time(void);
void update_coverage_time(void);
double total_coverage(int projection, int output, grid *g);

void intensity_edges(int left[2], int right[2], 
			    SphericalCoordinates *point,
			    int projection, grid *g);

void project_latlon_sinusoidal(double proj[2], LatLon *point);
void project_latlon_rectangular(double proj[2], LatLon *point);

#endif
/* !_STATS_UTILS_H_ */
