/*
 *****************************************************
 *
 *  SaVi by Robert Thurman (thurman@geom.umn.edu) and
 *          Patrick Worfolk (worfolk@alum.mit.edu).
 *
 *  Copyright (c) 1997 by The Geometry Center.
 *  This file is part of SaVi.  SaVi is free software;
 *  you can redistribute it and/or modify it only under
 *  the terms given in the file COPYRIGHT which you should
 *  have received along with this file.  SaVi may be
 *  obtained by emailing savi@geom.umn.edu.
 *
 *****************************************************
 *  
 * main.c
 *
 */

#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <time.h>

#include "utils.h"
#include "constants.h"
#include "globals.h"
#include "sats.h"
#include "tcl_utils.h"

static int check_run_permissions(void);
static void decode_cmd_line(int argc, char *argv[]);

int
main(int argc, char *argv[])
{
  char buf[] = "main(update)";

  /* exit if software expired */
/*  if (NOT_OK == check_run_permissions())
    error_and_exit("Sorry! SaVi software expired.\n
Email savi@geom.umn.edu to arrange for an updated version.");
*/

  /* decode command line */
  decode_cmd_line(argc, argv);

  /* initialize geomview if started as a module */
  if (TRUE == geomview_module) {
    if (NOT_OK == gv_init())
	error_and_exit("main: error in gv_init");
  } else {
    fprintf(stderr, "SaVi: For 3d visualization, run from geomview.\n");
  }
  
  /* initialize interface */
  if (NOT_OK == tk_init())
    error_and_exit("main: error in tk_init");


  /* load up a single satellite */
  sats_init();

  /* and update interface */
  tcl_script(buf);
  
  /* loop until exit */
  while ( ( OK == sats_update()) && (OK == tk_update()) );

  exit(0);
}

static void
decode_cmd_line(int argc, char *argv[])
{
  int i;

   for (i=1; i<argc; i++) {
     if (strcmp(argv[i], "-geomview") == 0)
       geomview_module = TRUE;
     else if (strcmp(argv[i], "-version") == 0) {
       error(Version);
       exit(0);
     } else {
       error_format("usage: %s [-geomview] [-version]", argv[0]);
       exit(1);
     }
   }
}

static int
check_run_permissions()
{
  time_t t;

  /* if at Univerisity of Minnesota then run */


  /* if before certain date then run */
  t = time(NULL);
  if ((t>0) && (t< 867400000))  /* 27.5 * 365.25 * 24 * 3600 */
    return OK;                  /* 1997 + 6 months */

  return NOT_OK;
}






