#
######################################################
#
#  SaVi by Robert Thurman (thurman@geom.umn.edu) and
#          Patrick Worfolk (worfolk@alum.mit.edu).
#
#  Copyright (c) 1997 by The Geometry Center.
#  This file is part of SaVi.  SaVi is free software;
#  you can redistribute it and/or modify it only under
#  the terms given in the file COPYRIGHT which you should
#  have received along with this file.  SaVi may be
#  obtained by emailing savi@geom.umn.edu.
#
######################################################
#  
# fisheye.tcl
#

proc fisheye(build) {} {
    global fisheye_flag Fisheye

    if [winfo exists .fisheye] {
	wm deiconify .fisheye
	raise .fisheye
	return
    }

    set name [build_Toplevel fisheye]

    build_Title $name "Fisheye view of the sky"

    set cmd [build_CmdFrame $name cmd]

    set p "$cmd.p"
    plot $p -bg black -width 300 -height 300
    pack $p

    build_LabelEntryColumns $cmd le1 \
	{label "" {time fisheye_lat_lon}}

    build_Optionslist $cmd olist \
	{"Show overhead satellites" fisheye_flag} \
	{"Leave vapor trails" fisheye_vapors_flag} \
	{"Reverse view" fisheye_reverse_view_flag} \
	{"Print inview times" fisheye_print_inview_flag}

    build_LabelEntryColumns $cmd le0 \
	{text " " {"Longitude:" "Latitiude:"}} \
	      {ientry "Degrees" {Fisheye(long_degrees) Fisheye(lat_degrees)} } \
	{ientry "Minutes" {Fisheye(long_minutes) Fisheye(lat_minutes)} }

    pack $cmd -fill both -expand 1

    build_DismissButtonbar $name dbbar fisheye(dismiss) \
	{"Apply" fisheye(apply)}

    # initialize display
    update
    $p clear
    $p plot 151 151 -symbol disk -size 149 -color white
    $p plot 151 151 -symbol circle -size 149 -color grey
    $p plot 151 151 -symbol circle -size  99 -color grey
    $p plot 151 151 -symbol circle -size  50 -color grey
    $p plot 151 151 -symbol point -size small -color grey
}

proc fisheye(dismiss) {} {
    global fisheye_flag

    set fisheye_flag 0
    destroy .fisheye
}

proc fisheye(update) {} {
    set flag fisheye_flag
    set fisheye_flag 1
    if {$flag == 0} {
	set fisheye_flag 0
    }
}

proc fisheye(apply) {} {
    global Fisheye
    satellites FISHEYE_SET $Fisheye(lat_degrees) $Fisheye(lat_minutes) \
	$Fisheye(long_degrees) $Fisheye(long_minutes)
}
